Create scaffolding for a new Leptos Component
Source:R/generic_input_init.R, R/generic_output_init.R
generic_component_init.RdThis function creates the necessary R, Rust, and TypeScript files for a new input or output component based on a generic template.